@@ -1,11 +1,11 @@
 ;;; vertico.el --- VERTical Interactive COmpletion -*- lexical-binding: t -*-
 
-;; Copyright (C) 2021-2023 Free Software Foundation, Inc.
+;; Copyright (C) 2021-2024 Free Software Foundation, Inc.
 
 ;; Author: Daniel Mendler <mail@daniel-mendler.de>
 ;; Maintainer: Daniel Mendler <mail@daniel-mendler.de>
 ;; Created: 2021
-;; Version: 1.5
+;; Version: 1.7
 ;; Package-Requires: ((emacs "27.1") (compat "29.1.4.4"))
 ;; Homepage: https://github.com/minad/vertico
 ;; Keywords: convenience, files, matching, completion
@@ -255,17 +255,17 @@ The function is configured by BY, BSIZE, BINDEX, BPRED and PRED."
     (if-let ((ann (or (vertico--metadata-get 'annotation-function)
                       (plist-get completion-extra-properties :annotation-function))))
         (cl-loop for cand in cands collect
-                 (let ((suffix (or (funcall ann cand) "")))
+                 (let ((suff (or (funcall ann cand) "")))
                    ;; The default completion UI adds the `completions-annotations'
                    ;; face if no other faces are present.
-                   (unless (text-property-not-all 0 (length suffix) 'face nil suffix)
-                     (setq suffix (propertize suffix 'face 'completions-annotations)))
-                   (list cand "" suffix)))
+                   (unless (text-property-not-all 0 (length suff) 'face nil suff)
+                     (setq suff (propertize suff 'face 'completions-annotations)))
+                   (list cand "" suff)))
       (cl-loop for cand in cands collect (list cand "" "")))))
 
 (defun vertico--move-to-front (elem list)
   "Move ELEM to front of LIST."
-  (if-let ((found (member elem list)))
+  (if-let ((found (member elem list))) ;; No duplicates, compare with Corfu.
       (nconc (list (car found)) (delq (setcar found nil) list))
     list))
 
@@ -416,15 +416,17 @@ The function is configured by BY, BSIZE, BINDEX, BPRED and PRED."
          (input (cons content pt)))
     (unless (or (and interruptible (input-pending-p)) (equal vertico--input input))
       ;; Redisplay to make input immediately visible before expensive candidate
-      ;; recomputation (#89).  No redisplay during init because of flicker.
+      ;; recomputation (gh:minad/vertico#89).  No redisplay during init because
+      ;; of flicker.
       (when (and interruptible (consp vertico--input))
         ;; Prevent recursive exhibit from timer (`consult-vertico--refresh').
         (cl-letf (((symbol-function #'vertico--exhibit) #'ignore)) (redisplay)))
       (pcase (let ((vertico--metadata (completion-metadata (substring content 0 pt)
                                                            minibuffer-completion-table
                                                            minibuffer-completion-predicate)))
-               ;; If Tramp is used, do not compute the candidates in an interruptible fashion,
-               ;; since this will break the Tramp password and user name prompts (See #23).
+               ;; If Tramp is used, do not compute the candidates in an
+               ;; interruptible fashion, since this will break the Tramp
+               ;; password and user name prompts (See gh:minad/vertico#23).
                (if (or (not interruptible)
                        (and (eq 'file (vertico--metadata-get 'category))
                             (or (vertico--remote-p content) (vertico--remote-p default-directory))))
@@ -481,9 +483,8 @@ The function is configured by BY, BSIZE, BINDEX, BPRED and PRED."
   "Format group TITLE given the current CAND."
   (when (string-prefix-p title cand)
     ;; Highlight title if title is a prefix of the candidate
-    (setq title (substring (funcall vertico--hilit
-                                    (propertize cand 'face 'vertico-group-title))
-                           0 (length title)))
+    (setq cand (propertize cand 'face 'vertico-group-title)
+          title (substring (funcall vertico--hilit cand) 0 (length title)))
     (vertico--remove-face 0 (length title) 'completions-first-difference title))
   (format (concat vertico-group-format "\n") title))
 
